@@ -5,8 +5,12 @@
     :url: https://blog.farmer233.top
     :date: 2021/09/04 23:39:20
 '''
+
+# INDEX http://192.168.2.123:7899/xtgl/index_initMenu.html?jsdm=xs&_t=1643879775142
+
 URL_ENDPOINT = {
     "HOME_URL": "/xtgl/login_slogin.html",
+    "INDEX_URL": "/xtgl/index_initMenu.html",
     'LOGIN': {
         'INDEX': '/xtgl/login_slogin.html',
         'CAPTCHA': '/zfcaptchaLogin',
