@@ -17,9 +17,12 @@ from school_sdk import SchoolClient
 
 gdust = SchoolClient('172.16.254.1', exist_verify=True)
 
-user = gdust.user_login('2018133209', '123qwe')
+user = gdust.user_login('2019131945', 'L2010578860')
 
-score = user.get_score(year=2020, term=2)
-print(score, type(score))
+# score = user.get_score(year=2020, term=2)
+# print(score, type(score))
+
+info = user.get_info()
+print(info)
 # with open("test\\data.json", 'w', encoding='utf-8') as f:
 #     f.write(json.dumps(score))
\ No newline at end of file
